"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Cell = void 0;
var _react = require("react");
var _reactNative = require("react-native");
var _jsxRuntime = require("react/jsx-runtime");
/**
 * cell component - the basic building block of the table
 */
const Cell = ({
  data,
  width,
  height,
  flex,
  style,
  textStyle,
  borderStyle,
  children,
  onPress,
  cellContainerProps = {},
  ...props
}) => {
  const textDom = children ?? /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.Text, {
    style: _reactNative.StyleSheet.flatten([textStyle]),
    ...props,
    children: data
  });
  const borderTopWidth = borderStyle?.borderWidth ?? 0;
  const borderRightWidth = borderTopWidth;
  const borderColor = borderStyle?.borderColor ?? '#000';
  const composedStyles = (0, _react.useMemo)(() => {
    const styles = {};
    if (width) styles.width = width;
    if (height) styles.height = height;
    if (flex) styles.flex = flex;
    if (!width && !flex && !height && !style) styles.flex = 1;
    return styles;
  }, [width, height, flex, style]);
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
    ...cellContainerProps,
    style: _reactNative.StyleSheet.flatten([{
      borderTopWidth,
      borderRightWidth,
      borderColor
    }, composedStyles, style, cellContainerProps.style, styles.cell]),
    children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.TouchableWithoutFeedback, {
      onPress: onPress ? () => onPress(data) : undefined,
      disabled: !onPress,
      children: /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
        style: [styles.touchableContainer, style],
        children: textDom
      })
    })
  });
};
exports.Cell = Cell;
const styles = _reactNative.StyleSheet.create({
  cell: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center'
  },
  touchableContainer: {
    flex: 1,
    width: '100%',
    justifyContent: 'center',
    alignItems: 'center'
  }
});
//# sourceMappingURL=cell.js.map