"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Rows = exports.Row = void 0;
var _react = require("react");
var _reactNative = require("react-native");
var _cell = require("./cell.js");
var _index = require("../util/index.js");
var _jsxRuntime = require("react/jsx-runtime");
/** Row component - Renders a single row of cells*/
const Row = ({
  data,
  style,
  widthArr,
  height,
  flexArr,
  textStyle,
  borderStyle,
  onPress,
  cellTextStyle,
  ...props
}) => {
  // calc total width based on width array
  const totalWidth = widthArr ? (0, _index.sum)(widthArr) : 0;

  // calc row styles based on props
  const rowStyle = (0, _react.useMemo)(() => {
    const styles = {};
    if (totalWidth) styles.width = totalWidth;
    if (height) styles.height = height;
    return styles;
  }, [totalWidth, height]);
  if (!data || !data.length) return null;
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
    style: [styles.row, rowStyle, style],
    children: data.map((item, index) => {
      const cellFlex = flexArr?.[index];
      const cellWidth = widthArr?.[index];
      const customTextStyle = cellTextStyle ? cellTextStyle(item, index) : undefined;
      return /*#__PURE__*/(0, _jsxRuntime.jsx)(_cell.Cell, {
        data: item,
        width: cellWidth,
        height: height,
        flex: cellFlex,
        borderStyle: borderStyle,
        textStyle: [customTextStyle, textStyle],
        onPress: onPress,
        ...props
      }, index);
    })
  });
};

/** Rows component - Renders multiple rows*/
exports.Row = Row;
const Rows = ({
  data,
  style,
  widthArr,
  heightArr,
  flexArr,
  textStyle,
  borderStyle,
  ...props
}) => {
  // calc total flex and width
  const totalFlex = flexArr ? (0, _index.sum)(flexArr) : 0;
  const totalWidth = widthArr ? (0, _index.sum)(widthArr) : 0;

  // calc container styles
  const containerStyle = (0, _react.useMemo)(() => {
    const styles = {};
    if (totalFlex) styles.flex = totalFlex;
    if (totalWidth) styles.width = totalWidth;
    return styles;
  }, [totalFlex, totalWidth]);
  if (!data || !data.length) return null;
  return /*#__PURE__*/(0, _jsxRuntime.jsx)(_reactNative.View, {
    style: containerStyle,
    children: data.map((rowData, index) => {
      const rowHeight = heightArr?.[index];
      return /*#__PURE__*/(0, _jsxRuntime.jsx)(Row, {
        data: rowData,
        widthArr: widthArr,
        height: rowHeight,
        flexArr: flexArr,
        style: style,
        textStyle: textStyle,
        borderStyle: borderStyle,
        ...props
      }, index);
    })
  });
};
exports.Rows = Rows;
const styles = _reactNative.StyleSheet.create({
  row: {
    flexDirection: 'row',
    overflow: 'hidden'
  }
});
//# sourceMappingURL=rows.js.map