"use strict";

import { useMemo } from 'react';
import { View, Text, StyleSheet, TouchableWithoutFeedback } from 'react-native';
import { jsx as _jsx } from "react/jsx-runtime";
/**
 * cell component - the basic building block of the table
 */
export const Cell = ({
  data,
  width,
  height,
  flex,
  style,
  textStyle,
  borderStyle,
  children,
  onPress,
  cellContainerProps = {},
  ...props
}) => {
  const textDom = children ?? /*#__PURE__*/_jsx(Text, {
    style: StyleSheet.flatten([textStyle]),
    ...props,
    children: data
  });
  const borderTopWidth = borderStyle?.borderWidth ?? 0;
  const borderRightWidth = borderTopWidth;
  const borderColor = borderStyle?.borderColor ?? '#000';
  const composedStyles = useMemo(() => {
    const styles = {};
    if (width) styles.width = width;
    if (height) styles.height = height;
    if (flex) styles.flex = flex;
    if (!width && !flex && !height && !style) styles.flex = 1;
    return styles;
  }, [width, height, flex, style]);
  return /*#__PURE__*/_jsx(View, {
    ...cellContainerProps,
    style: StyleSheet.flatten([{
      borderTopWidth,
      borderRightWidth,
      borderColor
    }, composedStyles, style, cellContainerProps.style, styles.cell]),
    children: /*#__PURE__*/_jsx(TouchableWithoutFeedback, {
      onPress: onPress ? () => onPress(data) : undefined,
      disabled: !onPress,
      children: /*#__PURE__*/_jsx(View, {
        style: [styles.touchableContainer, style],
        children: textDom
      })
    })
  });
};
const styles = StyleSheet.create({
  cell: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center'
  },
  touchableContainer: {
    flex: 1,
    width: '100%',
    justifyContent: 'center',
    alignItems: 'center'
  }
});
//# sourceMappingURL=cell.js.map