"use strict";

import { useMemo } from 'react';
import { View, StyleSheet } from 'react-native';
import { Cell } from "./cell.js";
import { sum } from "../util/index.js";

/** Row component - Renders a single row of cells*/
import { jsx as _jsx } from "react/jsx-runtime";
export const Row = ({
  data,
  style,
  widthArr,
  height,
  flexArr,
  textStyle,
  borderStyle,
  onPress,
  cellTextStyle,
  ...props
}) => {
  // calc total width based on width array
  const totalWidth = widthArr ? sum(widthArr) : 0;

  // calc row styles based on props
  const rowStyle = useMemo(() => {
    const styles = {};
    if (totalWidth) styles.width = totalWidth;
    if (height) styles.height = height;
    return styles;
  }, [totalWidth, height]);
  if (!data || !data.length) return null;
  return /*#__PURE__*/_jsx(View, {
    style: [styles.row, rowStyle, style],
    children: data.map((item, index) => {
      const cellFlex = flexArr?.[index];
      const cellWidth = widthArr?.[index];
      const customTextStyle = cellTextStyle ? cellTextStyle(item, index) : undefined;
      return /*#__PURE__*/_jsx(Cell, {
        data: item,
        width: cellWidth,
        height: height,
        flex: cellFlex,
        borderStyle: borderStyle,
        textStyle: [customTextStyle, textStyle],
        onPress: onPress,
        ...props
      }, index);
    })
  });
};

/** Rows component - Renders multiple rows*/
export const Rows = ({
  data,
  style,
  widthArr,
  heightArr,
  flexArr,
  textStyle,
  borderStyle,
  ...props
}) => {
  // calc total flex and width
  const totalFlex = flexArr ? sum(flexArr) : 0;
  const totalWidth = widthArr ? sum(widthArr) : 0;

  // calc container styles
  const containerStyle = useMemo(() => {
    const styles = {};
    if (totalFlex) styles.flex = totalFlex;
    if (totalWidth) styles.width = totalWidth;
    return styles;
  }, [totalFlex, totalWidth]);
  if (!data || !data.length) return null;
  return /*#__PURE__*/_jsx(View, {
    style: containerStyle,
    children: data.map((rowData, index) => {
      const rowHeight = heightArr?.[index];
      return /*#__PURE__*/_jsx(Row, {
        data: rowData,
        widthArr: widthArr,
        height: rowHeight,
        flexArr: flexArr,
        style: style,
        textStyle: textStyle,
        borderStyle: borderStyle,
        ...props
      }, index);
    })
  });
};
const styles = StyleSheet.create({
  row: {
    flexDirection: 'row',
    overflow: 'hidden'
  }
});
//# sourceMappingURL=rows.js.map