import type { FC } from 'react';
import React from 'react';
import { View, StyleSheet } from 'react-native';

import type { TableProps, TableWrapperProps } from '../types';

export const Table: FC<TableProps> = ({ style, borderStyle, children }) => {
  const borderLeftWidth = borderStyle?.borderWidth ?? 0;
  const borderBottomWidth = borderLeftWidth;
  const borderColor = borderStyle?.borderColor ?? '#000';

  const renderChildren = () =>
    React.Children.map(children, (child) => {
      if (!React.isValidElement(child)) return child;

      // check if we should add the border style | skip known type names
      const elementType = child.type as any;
      const isScrollView =
        elementType?.displayName === 'ScrollView' ||
        elementType?.name === 'ScrollView';

      if (borderStyle && !isScrollView) {
        return React.cloneElement(child, {
          borderStyle,
          ...child.props,
        });
      }

      return child;
    });

  return (
    <View
      style={StyleSheet.flatten([
        styles.table,
        style,
        {
          borderLeftWidth,
          borderBottomWidth,
          borderColor,
        },
      ])}
    >
      {renderChildren()}
    </View>
  );
};

export const TableWrapper: FC<TableWrapperProps> = ({
  style,
  borderStyle,
  children,
}) => {
  const renderChildren = () =>
    React.Children.map(children, (child) => {
      if (!React.isValidElement(child)) return child;

      if (borderStyle) {
        return React.cloneElement(child, {
          borderStyle,
          ...child.props,
        });
      }

      return child;
    });

  return (
    <View style={StyleSheet.flatten([styles.wrapper, style])}>
      {renderChildren()}
    </View>
  );
};

const styles = StyleSheet.create({
  table: {
    overflow: 'hidden',
  },
  wrapper: {
    flex: 1,
  },
});
